Struct lockchain_http::models::responses::OperationFailed[][src]

pub struct OperationFailed {
    pub explain: String,
    pub error: LockError,
}

A simple message that describes an invalid operation

explain() can return a localised string, that provides more details than the error itself.

LockError is a generic type provided by lockchain-core which is meant to represent any type of error that can occur in the lockchain ecosystem.

Fields